# SPDX-FileCopyrightText: 2022-2023 Helmholtz-Zentrum hereon GmbH
#
# SPDX-License-Identifier: CC0-1.0
# SPDX-License-Identifier: EUPL-1.2

"""
Django settings for the django-helmholtz-aai project.

Generated by 'django-admin startproject' using Django 3.2.15.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""
from __future__ import annotations

from email.utils import getaddresses
from pathlib import Path
from typing import List

import environ

env = environ.Env()

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


READ_DOT_ENV_FILE = env.bool("DJANGO_READ_DOT_ENV_FILE", default=False)
if READ_DOT_ENV_FILE:
    # OS environment variables take precedence over variables from .env
    env.read_env(str(BASE_DIR / ".env"))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = env(
    "DJANGO_SECRET_KEY",
    default="django-insecure-+_fai#*zi53=1w^y6hdai0spid)bvw2&$p=o952urq(iha2}",
)

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = env.bool("DEBUG", True)


if env.list("ALLOWED_HOSTS", default=[]):
    ALLOWED_HOSTS: List[str] = env.list("ALLOWED_HOSTS")

LOGIN_REDIRECT_URL = "/"
LOGIN_URL = "login"

# Application definition

INSTALLED_APPS = [
    "django_helmholtz_aai",
    "testproject",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

ROOT_URLCONF = "testproject.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

# ADMINS="Philipp S. Sommer <philipp.sommer@hereon.de>"
ADMINS = getaddresses(env.list("ADMINS", default=[]))

# MANAGERS="Philipp S. Sommer <philipp.sommer@hereon.de>"
MANAGERS = getaddresses(env.list("MANAGERS", default=[]))

WSGI_APPLICATION = "testproject.wsgi.application"

# Email settings
SERVER_EMAIL = env(
    "SERVER_EMAIL", default="no-reply.django-helmholtz-aai@example.com"
)

EMAIL_CONFIG = env.email(
    "EMAIL_URL", default="consolemail://user:password@localhost:25"
)

vars().update(EMAIL_CONFIG)

EMAIL_SUBJECT_PREFIX = "[django-helmholtz-aai] "


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

# isort: off
from . import database  # noqa: E402

# isort: on

DATABASES = {"default": database.config(env)}

CACHES = {"default": env.cache(default="dummycache://")}


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",  # noqa: E501
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",  # noqa: E501
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",  # noqa: E501
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",  # noqa: E501
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = "en"

TIME_ZONE = "UTC"

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = "/static/"

STATIC_ROOT = BASE_DIR / "static"
MEDIA_ROOT = BASE_DIR / "media" / "public"

MEDIA_URL = "/media/"

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

if env.bool("FORCE_HTTPS", default=False):
    SESSION_COOKIE_SECURE = True
    CSRF_COOKIE_SECURE = True

    SECURE_PROXY_SSL_HEADER = ("HTTP_X_FORWARDED_PROTO", "https")

ADMIN_LOCATION = env("ADMIN_LOCATION", default="admin/")

HELMHOLTZ_ALLOWED_VOS: list[str] = []

HELMHOLTZ_CLIENT_ID = env("HELMHOLTZ_CLIENT_ID", default=None)
HELMHOLTZ_CLIENT_SECRET = env("HELMHOLTZ_CLIENT_SECRET", default=None)

HELMHOLTZ_AAI_CONF_URL = env("HELMHOLTZ_AAI_CONF_URL", default=None)

HELMHOLTZ_CREATE_USERS_STRATEGY = [
    "manual-new",
    "map-existing",
    "no-duplicated-helmholtz",
]
